@@ -1,4 +1,5 @@
 # shadowstep/elements/elements.py
+
 from typing import Callable, Iterator, List, Optional
 
 class Elements:
@@ -28,6 +29,9 @@ class Elements:
         """Filter elements with predicate."""
         return Elements(lambda: (el for el in self._factory() if predicate(el)))
 
+    def next(self):
+        raise NotImplementedError
+
     @property
     def should(self) -> 'ShouldElements':
         from shadowstep.elements.should import ShouldElements
